@@ -4,7 +4,9 @@ from .contentviews import *
 
 course = Course('git',
                 'Git',
-                [(GitIgnoreConceptView,[GitStageChangesView]),
+                [(GitBasicsSelfTestView,[GitPullBasicsView,GitRmView,GitAddRemoteView,GitLogView,GitStatusAndGitIgnoreView]),
+                 (GitRmView,[GitStageChangesView]),
+                 (GitIgnoreConceptView,[GitStageChangesView]),
                  (GitStatusView,[GitStageChangesView]),
                  (GitPushView,[GitStageChangesView,GitRemotesConceptView]),
                  (GitAddRemoteView,[GitRemotesConceptView]),
@@ -15,5 +17,4 @@ course = Course('git',
                  (GitRemotesConceptView,[GitStagesView]),
                  (GitStagesView,[GitInitView]),
                  (GitInitView,[WhatIsGitView]),
-                 (WhatIsGitView,[])],
-                "git@github.com:v-nys/git-modeloplossingen.git")
+                 (WhatIsGitView,[])])
